.. SED Fitter documentation master file, created by
   sphinx-quickstart on Tue Sep  3 17:16:10 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Python SED Fitter's documentation
=================================

This package is an experimental Python port of the SED Fitting tool described in
`Robitaille et al. (2007) <http://adsabs.harvard.edu/abs/2007ApJS..169..328R>`_
and is still under active development.

.. toctree::
   :maxdepth: 1

   introduction.rst
   installation.rst
   data.rst
   fitting.rst
   model_packages.rst
   filter_names.rst
   select_syntax.rst
   api/api.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

